CHANGELOG
=========

0.0.10
------
* Added minimal package functionality: query (responses, certs, domains), count (responses, certs, domains), responses statistics, profile data, host information (ip, domain), download bulk data (responses, certs, domains)
* Added minimal CLI functionality: query (responses, certs, domains), count (responses, certs, domains), responses statistics, profile data, host information (ip, domain), download bulk data (responses, certs, domains)


0.0.1
------
* Initial package